# rac_es

Helpers for Elasticsearch, including Analyzers and Documents.

## Setup

Make sure this library is installed:

    $ pip install git+git://github.com/RockefellerArchiveCenter/rac_es.git


## Usage

You can then use `rac_es` in your python scripts by importing it:

    import rac_es


## License

This code is released under an [MIT License](LICENSE).
